==> qtjambi-printsupport-debuginfo-windows-x64-6.6.0.jar: sources/QtJambiPrintSupport/QPrinter_shell.h <==
#ifndef QPRINTER_SHELL_H
#define QPRINTER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#if __has_include(<QtPrintSupport/qprinter.h>)
#include <QtPrintSupport/qprinter.h>
#endif
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qmargins.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtGui/qpagedpaintdevice.h>
#include <QtGui/qpagelayout.h>
#include <QtGui/qpageranges.h>
#include <QtGui/qpagesize.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtPrintSupport/qprintengine.h>
#include <QtPrintSupport/qprinterinfo.h>
#include <QtJambi/RegistryAPI>


#if !defined(QT_NO_PRINTER)

class QPrinter_shell : public QPrinter, public QtJambiShellInterface
{
public:
    QPrinter_shell(QPrinter::PrinterMode mode0 = QPrinter::ScreenResolution);
    QPrinter_shell(const QPrinterInfo& printer0, QPrinter::PrinterMode mode1 = QPrinter::ScreenResolution);
    ~QPrinter_shell() override;

    void initPainter(QPainter* painter0) const override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    bool newPage() override;
    QPaintEngine* paintEngine() const override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    bool setPageLayout(const QPageLayout& pageLayout0) override;
    bool setPageMargins(const QMarginsF& margins0, QPageLayout::Unit units1) override;
    bool setPageOrientation(QPageLayout::Orientation orientation0) override;
    void setPageRanges(const QPageRanges& ranges0) override;
    bool setPageSize(const QPageSize& pageSize0) override;
    QPainter* sharedPainter() const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPrinter_access : public QPrinter
{
    void __qt_setEngines_QPrintEngine_ptr_QPaintEngine_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID printEngine0, QtJambiNativeID paintEngine1);
    void __qt_initPainter_QPainter_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0) const;
    jint __qt_metric_QPaintDevice_PaintDeviceMetric_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1) const;
    jboolean __qt_newPage(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_paintEngine(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_redirected_QPoint_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID offset0) const;
    jboolean __qt_setPageLayout_cref_QPageLayout(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID pageLayout0);
    jboolean __qt_setPageMargins_cref_QMarginsF_QPageLayout_Unit(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID margins0, jint units1);
    jboolean __qt_setPageOrientation_QPageLayout_Orientation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint orientation0);
    void __qt_setPageRanges_cref_QPageRanges(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID ranges0);
    jboolean __qt_setPageSize_cref_QPageSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID pageSize0);
    jobject __qt_sharedPainter(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // !defined(QT_NO_PRINTER)
#endif // QPRINTER_SHELL_H

==> qtjambi-printsupport-debuginfo-windows-x64-6.6.1.jar: sources/QtJambiPrintSupport/QPrinter_shell.h <==
#ifndef QPRINTER_SHELL_H
#define QPRINTER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#if __has_include(<QtPrintSupport/qprinter.h>)
#include <QtPrintSupport/qprinter.h>
#endif
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qmargins.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtGui/qpagedpaintdevice.h>
#include <QtGui/qpagelayout.h>
#include <QtGui/qpageranges.h>
#include <QtGui/qpagesize.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#if __has_include(<QtPrintSupport/qprintengine.h>)
#include <QtPrintSupport/qprintengine.h>
#endif
#if __has_include(<QtPrintSupport/qprinterinfo.h>)
#include <QtPrintSupport/qprinterinfo.h>
#endif
#include <QtJambi/RegistryAPI>


#if !defined(QT_NO_PRINTER)

class QPrinter_shell : public QPrinter, public QtJambiShellInterface
{
public:
    QPrinter_shell(QPrinter::PrinterMode mode0 = QPrinter::ScreenResolution);
    QPrinter_shell(const QPrinterInfo& printer0, QPrinter::PrinterMode mode1 = QPrinter::ScreenResolution);
    ~QPrinter_shell() override;

    void initPainter(QPainter* painter0) const override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    bool newPage() override;
    QPaintEngine* paintEngine() const override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    bool setPageLayout(const QPageLayout& pageLayout0) override;
    bool setPageMargins(const QMarginsF& margins0, QPageLayout::Unit units1) override;
    bool setPageOrientation(QPageLayout::Orientation orientation0) override;
    void setPageRanges(const QPageRanges& ranges0) override;
    bool setPageSize(const QPageSize& pageSize0) override;
    QPainter* sharedPainter() const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPrinter_access : public QPrinter
{
    void __qt_setEngines_QPrintEngine_ptr_QPaintEngine_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID printEngine0, QtJambiNativeID paintEngine1);
    void __qt_initPainter_QPainter_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0) const;
    jint __qt_metric_QPaintDevice_PaintDeviceMetric_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1) const;
    jboolean __qt_newPage(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_paintEngine(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_redirected_QPoint_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID offset0) const;
    jboolean __qt_setPageLayout_cref_QPageLayout(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID pageLayout0);
    jboolean __qt_setPageMargins_cref_QMarginsF_QPageLayout_Unit(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID margins0, jint units1);
    jboolean __qt_setPageOrientation_QPageLayout_Orientation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint orientation0);
    void __qt_setPageRanges_cref_QPageRanges(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID ranges0);
    jboolean __qt_setPageSize_cref_QPageSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID pageSize0);
    jobject __qt_sharedPainter(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // !defined(QT_NO_PRINTER)
#endif // QPRINTER_SHELL_H
